@@ -2,7 +2,7 @@ use ukanren::*;
 
 #[test]
 fn void_goal() {
-    let mut iter = fresh(|x| eq(&x, &x)).run(1);
+    let mut iter = run(|x| eq(&x, &x));
     assert_eq!(iter.next(), Some(state![_]));
     assert_eq!(iter.next(), None);
 }
@@ -11,7 +11,7 @@ fn void_goal() {
 fn chained_disjunction() {
     let numbers = |x| eq(&x, &1).or(eq(&x, &2)).or(eq(&x, &3)).boxed();
 
-    let mut iter = fresh(numbers).run(1);
+    let mut iter = run(numbers);
     assert_eq!(iter.next(), Some(state![1]));
     assert_eq!(iter.next(), Some(state![3]));
     assert_eq!(iter.next(), Some(state![2]));
@@ -24,7 +24,7 @@ fn interleaving() {
         eq(&x, &n).or(delay(move || inf(x.clone(), n))).boxed()
     }
 
-    let mut iter = fresh(|x: Value| inf(x.clone(), 5).or(inf(x, 6))).run(1);
+    let mut iter = run(|x: Value| inf(x.clone(), 5).or(inf(x, 6)));
     for _ in 0..10 {
         assert_eq!(iter.next(), Some(state![5]));
         assert_eq!(iter.next(), Some(state![6]));
@@ -33,15 +33,14 @@ fn interleaving() {
 
 #[test]
 fn two_equal() {
-    let mut iter = fresh(|x, y| eq(&x, &y)).run(2);
+    let mut iter = run(|x, y| eq(&x, &y));
     assert_eq!(iter.next(), Some(state![_, (@0)]));
     assert_eq!(iter.next(), None);
 }
 
 #[test]
 fn multi_equal() {
-    let mut iter =
-        fresh(|x, y, z, w| eq(&x, &y).and(eq(&z, &w)).or(eq(&x, &z).and(eq(&y, &w)))).run(4);
+    let mut iter = run(|x, y, z, w| eq(&x, &y).and(eq(&z, &w)).or(eq(&x, &z).and(eq(&y, &w))));
     assert_eq!(iter.next(), Some(state![_, (@0), _, (@2)]));
     assert_eq!(iter.next(), Some(state![_, _, (@0), (@1)]));
     assert_eq!(iter.next(), None);
@@ -49,7 +48,7 @@ fn multi_equal() {
 
 #[test]
 fn list_equal() {
-    let mut iter = fresh(|x, y| eq(&[x, y], &["hello", "world"])).run(2);
+    let mut iter = run(|x, y| eq(&[x, y], &["hello", "world"]));
     assert_eq!(iter.next(), Some(state!["hello", "world"]));
     assert_eq!(iter.next(), None);
 }
